@@ -174,7 +174,7 @@ py_discover_config <- function(required_module = NULL) {
 }
 
 
-#' Discover versions of Python installed on a Widnows system
+#' Discover versions of Python installed on a Windows system
 #' 
 #' @return Data frame with `type`, `hive`, `install_path`, `executable_path`,
 #'   and `version`.
@@ -216,7 +216,10 @@ python_environments <- function(env_dirs, required_module = NULL) {
   }
   
   # filter by existence
-  envs[file.exists(envs)]
+  if (length(envs) > 0)
+    envs[file.exists(envs)]
+  else
+    envs
 }
 
 
@@ -433,7 +436,7 @@ windows_registry_anaconda_versions <- function() {
 }
 
 read_python_versions_from_registry <- function(hive, key,type=key) {
-  versions <- c()
+  
   python_core_key <- tryCatch(utils::readRegistry(
     key = paste0("SOFTWARE\\Python\\", key), hive = hive, maxdepth = 3),
     error = function(e) NULL)
@@ -452,53 +455,62 @@ read_python_versions_from_registry <- function(hive, key,type=key) {
       if (is.list(version_key) && !is.null(version_key$InstallPath)) {
         version_dir <- version_key$InstallPath$`(Default)`
         if (!is.null(version_dir) && utils::file_test("-d", version_dir)) {
-          types <- c(types, type)
-          hives <- c(hives, hive)
-          install_path <- version_dir
-          install_paths <- c(install_paths, utils::shortPathName(install_path))
-          executable_path <- file.path(install_path, "python.exe")
-          executable_paths <- c(executable_paths, utils::shortPathName(executable_path))
           
-          # determine version and arch
-          if (type == "Anaconda") {
-            matches <- regexec("^Anaconda(\\d)(\\d)-(32|64)$", version)
-            matches <- regmatches(version, matches)[[1]]
-            if (length(matches) == 4) {
-              version <- paste(matches[[2]], matches[[3]], sep = ".")
-              arch <- matches[[4]]
-            } else {
-              warning("Unexpected format for Anaconda version: ", version)
-              arch <- NA
-            }
-          } else { # type == "PythonCore"
-            matches <- regexec("^(\\d)\\.(\\d)(?:-(32|64))?$", version)
-            matches <- regmatches(version, matches)[[1]]
-            if (length(matches) == 4) {
-              version <- paste(matches[[2]], matches[[3]], sep = ".")
-              arch <- matches[[4]]
-              if (!nzchar(arch)) {
-                if (numeric_version(version) >= "3.0")
-                  arch <- "64"
-                else {
-                  python_arch <- python_arch(executable_path)
-                  arch <- gsub("bit", "", python_arch, fixed = TRUE)
-                }
+          # determine install_path and executable_path
+          install_path <- version_dir
+          executable_path <- file.path(install_path, "python.exe")
+          
+          # proceed if it exists
+          if (file.exists(executable_path)) {
+          
+            # determine version and arch
+            if (type == "Anaconda") {
+              matches <- regexec("^Anaconda.*(32|64).*$", version)
+              matches <- regmatches(version, matches)[[1]]
+              if (length(matches) == 2) {
+                version <- version_key$SysVersion
+                arch <- matches[[2]]
+              } else {
+                warning("Unexpected format for Anaconda version: ", version,
+                        "\n(Please install a more recent version of Anaconda)")
+                arch <- NA
               }
-            } else {
-              warning("Unexpected format for PythonCore version: ", version)
-              arch <- NA
+            } else { # type == "PythonCore"
+              matches <- regexec("^(\\d)\\.(\\d)(?:-(32|64))?$", version)
+              matches <- regmatches(version, matches)[[1]]
+              if (length(matches) == 4) {
+                version <- paste(matches[[2]], matches[[3]], sep = ".")
+                arch <- matches[[4]]
+                if (!nzchar(arch)) {
+                  if (numeric_version(version) >= "3.0")
+                    arch <- "64"
+                  else {
+                    python_arch <- python_arch(executable_path)
+                    arch <- gsub("bit", "", python_arch, fixed = TRUE)
+                  }
+                }
+              } else {
+                warning("Unexpected format for PythonCore version: ", version)
+                arch <- NA
+              }
+            }
+            
+            if (!is.na(arch)) {
+              # convert to R arch
+              if (arch == "32")
+                arch <- "i386"
+              else if (arch == "64")
+                arch <- "x64"
+              
+              # append to vectors
+              types <- c(types, type)
+              hives <- c(hives, hive)
+              install_paths <- c(install_paths, utils::shortPathName(install_path))
+              executable_paths <- c(executable_paths, utils::shortPathName(executable_path))
+              versions <- c(versions, version)
+              archs <- c(archs, arch)
             }
           }
-          
-          # convert to R arch
-          if (arch == "32")
-            arch <- "i386"
-          else if (arch == "64")
-            arch <- "x64"
-          
-          
-          versions <- c(versions, version)
-          archs <- c(archs, arch)
         }
       }
     }
