@@ -93,6 +93,7 @@ conda_list <- function(conda = "auto") {
   
   # list envs
   conda_envs <- system2(conda, args = c("info", "--envs"), stdout = TRUE)
+  conda_envs <- conda_envs[!grepl("Anaconda Cloud", conda_envs, fixed = TRUE)]
   matches <- regexec(paste0("^([^#][^ ]+)[ \\*]+(.*)$"), conda_envs)
   matches <- regmatches(conda_envs, matches)
   
@@ -211,6 +212,14 @@ conda_binary <- function(conda = "auto") {
 }
 
 
+#' @rdname conda-tools
+#' @export
+conda_version <- function(conda = "auto") {
+  conda_bin <- conda_binary(conda)
+  system2(conda_bin, "--version", stdout = TRUE)
+}
+
+
 
 find_conda <- function() {
   conda <- Sys.which("conda")
